<?php
/**
 * Logout - Backoffice administrativo
 * Turpial Airlines, C.A.
 */

session_start();
require_once '../includes/functions.php';
require_once '../includes/User.php';

$user = new User();
$user->logout();

header('Location: login.php?message=logged_out');
exit;
?>