<?php
/**
 * Layout header para frontend público
 * Turpial Airlines, C.A.
 */

// Detectar automáticamente la ruta raíz del proyecto
$project_root = dirname(dirname(__DIR__));

// Incluir archivos con rutas absolutas
require_once $project_root . '/includes/functions.php';
require_once $project_root . '/includes/Division.php';

$division = new Division();
$divisions = $division->getWithCategories();
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo isset($page_title) ? $page_title . ' - ' : ''; ?>Turpial Airlines - Oportunidades de Empleo</title>
    <meta name="description" content="Descubre las mejores oportunidades de empleo en Turpial Airlines, C.A. Únete a nuestro equipo y construye tu carrera en la industria aeronáutica.">
    <meta name="keywords" content="empleos, trabajos, aerolínea, aviación, turpial airlines, venezuela, vacantes">
    
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <!-- Custom CSS -->
    <?php
    // Calcular la ruta del CSS basada en la ubicación actual
    $css_path = dirname(dirname($_SERVER['PHP_SELF'])) . '/assets/css/style.css';
    ?>
    <link href="<?php echo $css_path; ?>" rel="stylesheet">
    
    <!-- Favicon -->
    <link rel="icon" type="image/x-icon" href="assets/images/favicon.ico">
</head>
<body>
    <!-- Header -->
    <header class="header">
        <nav class="navbar navbar-expand-lg">
            <div class="container">
                <a class="navbar-brand" href="index.php">
                    <i class="fas fa-plane-departure me-2"></i>
                    Turpial Airlines
                </a>
                
                <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                    <span class="navbar-toggler-icon"></span>
                </button>
                
                <div class="collapse navbar-collapse" id="navbarNav">
                    <ul class="navbar-nav ms-auto">
                        <li class="nav-item">
                            <a class="nav-link" href="index.php">
                                <i class="fas fa-home me-1"></i>Inicio
                            </a>
                        </li>
                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle" href="#" role="button" data-bs-toggle="dropdown">
                                <i class="fas fa-briefcase me-1"></i>Vacantes
                            </a>
                            <ul class="dropdown-menu">
                                <li><a class="dropdown-item" href="jobs.php">Todas las Vacantes</a></li>
                                <li><hr class="dropdown-divider"></li>
                                <?php foreach ($divisions as $div): ?>
                                    <li><a class="dropdown-item" href="jobs.php?division=<?php echo $div['id']; ?>"><?php echo escape($div['name']); ?></a></li>
                                <?php endforeach; ?>
                            </ul>
                        </li>
                       
                        <li class="nav-item">
                            <a class="nav-link" href="#contact">
                                <i class="fas fa-envelope me-1"></i>Contacto
                            </a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" href="../admin/login.php">
                                <i class="fas fa-user-shield me-1"></i>Admin
                            </a>
                        </li>
                    </ul>
                </div>
            </div>
        </nav>
    </header>

    <main>
