/*
SQLyog Community v13.3.0 (64 bit)
MySQL - 10.4.32-MariaDB : Database - turpial_jobs
*********************************************************************
*/

/*!40101 SET NAMES utf8 */;

/*!40101 SET SQL_MODE=''*/;

/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;
CREATE DATABASE /*!32312 IF NOT EXISTS*/`turpial_jobs` /*!40100 DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci */;

USE `turpial_jobs`;

/*Table structure for table `applications` */

DROP TABLE IF EXISTS `applications`;

CREATE TABLE `applications` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `job_vacancy_id` int(11) NOT NULL,
  `full_name` varchar(100) NOT NULL,
  `email` varchar(100) NOT NULL,
  `phone` varchar(20) DEFAULT NULL,
  `address` text DEFAULT NULL,
  `city` varchar(50) DEFAULT NULL,
  `country` varchar(50) DEFAULT 'Venezuela',
  `education_level` varchar(50) DEFAULT NULL,
  `years_experience` int(11) DEFAULT 0,
  `current_position` varchar(100) DEFAULT NULL,
  `cover_letter` text DEFAULT NULL,
  `cv_filename` varchar(255) DEFAULT NULL,
  `cv_path` varchar(500) DEFAULT NULL,
  `application_date` timestamp NOT NULL DEFAULT current_timestamp(),
  `status` enum('Pendiente','En Revisión','Entrevista','Seleccionado','Rechazado') DEFAULT 'Pendiente',
  `notes` text DEFAULT NULL,
  `reviewed_by` int(11) DEFAULT NULL,
  `reviewed_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `reviewed_by` (`reviewed_by`),
  KEY `idx_applications_job_vacancy` (`job_vacancy_id`),
  KEY `idx_applications_status` (`status`),
  KEY `idx_applications_date` (`application_date`),
  CONSTRAINT `applications_ibfk_1` FOREIGN KEY (`job_vacancy_id`) REFERENCES `job_vacancies` (`id`) ON DELETE CASCADE,
  CONSTRAINT `applications_ibfk_2` FOREIGN KEY (`reviewed_by`) REFERENCES `users` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=9 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

/*Data for the table `applications` */

insert  into `applications`(`id`,`job_vacancy_id`,`full_name`,`email`,`phone`,`address`,`city`,`country`,`education_level`,`years_experience`,`current_position`,`cover_letter`,`cv_filename`,`cv_path`,`application_date`,`status`,`notes`,`reviewed_by`,`reviewed_at`) values 
(1,1,'Juan Carlos Pérez','jcperez@email.com','+58-414-123-4567','Av. Libertador, Caracas','Caracas','Venezuela','Ingeniero en Sistemas',4,'Desarrollador Senior','Estimados señores, me dirijo a ustedes para expresar mi interés en la posición de Desarrollador Full Stack PHP. Cuento con 4 años de experiencia en desarrollo web con PHP y Laravel.',NULL,NULL,'2025-10-07 16:29:28','En Revisión',NULL,NULL,'2025-10-03 17:00:23'),
(2,1,'María Alejandra Rodríguez','marodriguez@email.com','+58-412-987-6543','Urbanización El Rosal, Caracas','Caracas','Venezuela','Ingeniero en Informática',3,'Desarrolladora Web','Me complace postularme para el cargo de Desarrollador Full Stack PHP. Mi experiencia incluye desarrollo con PHP, MySQL y frameworks modernos.',NULL,NULL,'2025-10-07 16:29:28','Entrevista',NULL,NULL,'2025-10-03 17:00:14'),
(3,2,'Carlos Eduardo Martínez','cemartinez@email.com','+58-426-555-1234','Los Palos Grandes, Caracas','Caracas','Venezuela','Ingeniero en Sistemas',3,'Analista Programador','Solicito consideración para la posición de Analista de Sistemas. Tengo experiencia en análisis de requerimientos y diseño de sistemas.',NULL,NULL,'2025-10-07 16:29:28','En Revisión',NULL,NULL,'2025-10-03 17:00:11'),
(4,4,'Roberto Antonio Silva','rasilva@email.com','+58-414-777-8888','Altamira, Caracas','Caracas','Venezuela','Piloto Comercial',8,'Comandante B737','Me dirijo a ustedes para postularme como Comandante A320. Cuento con más de 5000 horas de vuelo y type rating vigente.',NULL,NULL,'2025-10-07 16:29:28','Seleccionado',NULL,NULL,'2025-10-06 17:00:18'),
(5,5,'Ana Isabel Fernández','aifernandez@email.com','+58-412-333-2222','Las Mercedes, Caracas','Caracas','Venezuela','Curso TCP',1,'Auxiliar de Vuelo','Deseo postularme para la posición de Auxiliar de Vuelo. Soy egresada del curso TCP y tengo experiencia en servicio al cliente.',NULL,NULL,'2025-10-07 16:29:28','Rechazado',NULL,NULL,'2025-10-06 17:00:06'),
(6,1,'JAVIER','JART30@GMAIL.COM','+584121117228','DSDASFDASFDASF','VALENCIA','Venezuela','TSU',10,'DESARROLLADOR FULL STACK','ASCASCASCASCASCASCASCASCASCASCASCASCASCASCASCDBNGHMKJ,KJ,.HJMGHMHJ,HJMGHNDGFBDFBDFBDFBDFBDFBDFBDFBDFBDFBDFBDFBDFGBGFNGHMHJMHJMHJM','Turpial_Aerea.pdf','../uploads/68e69c9821646_1759943832.pdf','2025-10-08 13:17:12','Seleccionado','',1,'2025-10-13 10:05:43'),
(7,5,'PEDRO PEREZ','PEDRO@ANALIZTA.COM','+584142323235','EDO ARAGUA','MARACAY,ARAGUA','Venezuela','Especialista',10,'AUXILIAR DE VUELO','YTYYTGBHDFBVFKEVNDKJAISVNDOSVNDOVNDWOVNDVNXKLSVNDKJSVNCKJSVNCKSJVNCKJSVNSCDJVNDSOJVNDSOVINOIVNCKLSVNJXCVBUDASWFHDWIFDFUREWGFGFREWOHICSBKJ VxzCVBKDASVBKJxczsBKJVBCKJSVBKLJXCSBKLJVCVXC','lineas corporativas.docx','../uploads/68ed127163daa_1760367217.docx','2025-10-13 10:53:37','Pendiente',NULL,NULL,NULL),
(8,6,'FRANCYS SILVA','FSILVA@GMAIL.COM','+5841425252525','DSGDFGDFSGDFHDGFGHFJHJKHJKHJKHJKHJKHJKHJKHJKHJKHJKHJKHJKHJKGH','NAGUANAGUA','Venezuela','Universitario',10,'AUXILIAR','DFGDFSGDFSGDFSGDFSGDFGMDFKLBMDFBMFÑLBMDÑFLBMPEBMEBMOEBMOREMBOPFEBMMRFEBOMREFBDFSGFGDFGDFSGDFSGDFSGDFSGSDFSGDFSGDFGDFGDFGDFGDFGDFGDFGDFSGDFSGDS','Listado.pdf','../uploads/68ed25b30a85e_1760372147.pdf','2025-10-13 12:15:47','Pendiente',NULL,NULL,NULL);

/*Table structure for table `categories` */

DROP TABLE IF EXISTS `categories`;

CREATE TABLE `categories` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `division_id` int(11) NOT NULL,
  `name` varchar(100) NOT NULL,
  `description` text DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT 1,
  `created_at` timestamp NOT NULL DEFAULT current_timestamp(),
  `updated_at` timestamp NOT NULL DEFAULT current_timestamp() ON UPDATE current_timestamp(),
  PRIMARY KEY (`id`),
  KEY `idx_categories_division` (`division_id`),
  CONSTRAINT `categories_ibfk_1` FOREIGN KEY (`division_id`) REFERENCES `divisions` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=14 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

/*Data for the table `categories` */

insert  into `categories`(`id`,`division_id`,`name`,`description`,`is_active`,`created_at`,`updated_at`) values 
(1,1,'IT y Desarrollo','Programación, desarrollo web y aplicaciones',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(2,1,'Infraestructura','Redes, servidores y telecomunicaciones',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(3,1,'Soporte Técnico','Mesa de ayuda y soporte a usuarios',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(4,2,'Pilotos','Personal de vuelo - Comandantes y copilotos',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(5,2,'Tripulación de Cabina','Auxiliares de vuelo y sobrecargos',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(6,2,'Mantenimiento','Técnicos de mantenimiento aeronáutico',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(7,3,'Ventas','Agentes de ventas y reservas',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(8,3,'Marketing','Mercadeo y publicidad',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(9,3,'Atención al Cliente','Servicio al cliente y call center',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(10,4,'Recursos Humanos','Personal de RRHH y reclutamiento',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(11,4,'Finanzas','Contabilidad, finanzas y auditoría',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(12,5,'Seguridad Aeroportuaria','Personal de seguridad en aeropuertos',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(13,5,'Seguridad Corporativa','Seguridad de instalaciones y personal',1,'2025-10-07 16:28:48','2025-10-07 16:28:48');

/*Table structure for table `divisions` */

DROP TABLE IF EXISTS `divisions`;

CREATE TABLE `divisions` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) NOT NULL,
  `description` text DEFAULT NULL,
  `manager` varchar(100) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT 1,
  `created_at` timestamp NOT NULL DEFAULT current_timestamp(),
  `updated_at` timestamp NOT NULL DEFAULT current_timestamp() ON UPDATE current_timestamp(),
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

/*Data for the table `divisions` */

insert  into `divisions`(`id`,`name`,`description`,`manager`,`is_active`,`created_at`,`updated_at`) values 
(1,'División de Sistemas','Tecnología e informática de la aerolínea','Carlos Rodríguez',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(2,'División de Operaciones','Operaciones de vuelo y mantenimiento','Ana Martínez',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(3,'Dirección de  Comercialización','Ventas, marketing y atención al cliente','Alejandro Dugarte',1,'2025-10-07 16:28:48','2025-10-13 12:18:01'),
(4,'División Administrativa','Recursos humanos, finanzas y contabilidad','María Fernández',1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(5,'División de Seguridad','Seguridad aeroportuaria y corporativa','Roberto Silva',1,'2025-10-07 16:28:48','2025-10-07 16:28:48');

/*Table structure for table `job_vacancies` */

DROP TABLE IF EXISTS `job_vacancies`;

CREATE TABLE `job_vacancies` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `category_id` int(11) NOT NULL,
  `title` varchar(200) NOT NULL,
  `description` text NOT NULL,
  `requirements` text DEFAULT NULL,
  `responsibilities` text DEFAULT NULL,
  `salary_range` varchar(100) DEFAULT NULL,
  `employment_type` enum('Tiempo Completo','Medio Tiempo','Contrato','Pasantía') DEFAULT 'Tiempo Completo',
  `location` varchar(100) DEFAULT NULL,
  `experience_required` varchar(50) DEFAULT NULL,
  `education_required` varchar(100) DEFAULT NULL,
  `deadline` date DEFAULT NULL,
  `max_applicants` int(11) DEFAULT 0,
  `is_active` tinyint(1) DEFAULT 1,
  `is_featured` tinyint(1) DEFAULT 0,
  `created_by` int(11) DEFAULT NULL,
  `created_at` timestamp NOT NULL DEFAULT current_timestamp(),
  `updated_at` timestamp NOT NULL DEFAULT current_timestamp() ON UPDATE current_timestamp(),
  PRIMARY KEY (`id`),
  KEY `created_by` (`created_by`),
  KEY `idx_job_vacancies_category` (`category_id`),
  KEY `idx_job_vacancies_active` (`is_active`),
  CONSTRAINT `job_vacancies_ibfk_1` FOREIGN KEY (`category_id`) REFERENCES `categories` (`id`) ON DELETE CASCADE,
  CONSTRAINT `job_vacancies_ibfk_2` FOREIGN KEY (`created_by`) REFERENCES `users` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=9 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

/*Data for the table `job_vacancies` */

insert  into `job_vacancies`(`id`,`category_id`,`title`,`description`,`requirements`,`responsibilities`,`salary_range`,`employment_type`,`location`,`experience_required`,`education_required`,`deadline`,`max_applicants`,`is_active`,`is_featured`,`created_by`,`created_at`,`updated_at`) values 
(1,1,'Desarrollador Full Stack PHP','Buscamos un desarrollador experimentado en PHP para unirse a nuestro equipo de desarrollo de sistemas corporativos de Turpial Airlines.','Conocimientos sólidos en PHP 8+, MySQL, JavaScript, HTML5, CSS3, Framework Laravel o similar, Git, APIs REST','Desarrollar y mantener aplicaciones web, Colaborar con el equipo de UX/UI, Optimizar el rendimiento de las aplicaciones, Participar en revisiones de código','$800 - $1,500 USD','Tiempo Completo','Caracas, Venezuela','3-5 años','Ingeniero en Sistemas o afín','2025-11-15',0,1,0,1,'2025-10-07 16:29:28','2025-10-07 16:29:28'),
(2,1,'Analista de Sistemas','Analista de sistemas para el área de IT, responsable del análisis y diseño de soluciones tecnológicas para la aerolínea.','Experiencia en análisis de sistemas, UML, Base de datos, Metodologías ágiles, Conocimiento del sector aeronáutico (deseable)','Analizar requerimientos de usuarios, Diseñar soluciones tecnológicas, Documentar procesos y sistemas, Coordinar con desarrolladores','$600 - $1,000 USD','Tiempo Completo','Caracas, Venezuela','2-4 años','Ingeniero en Sistemas','2025-10-30',0,1,0,1,'2025-10-07 16:29:28','2025-10-07 16:29:28'),
(3,2,'Administrador de Redes','Administrador de infraestructura de redes para mantener la conectividad crítica de nuestras operaciones.','Certificaciones Cisco CCNA/CCNP, Experiencia con equipos de red, Conocimiento de protocolos TCP/IP, VPN, Firewall','Administrar equipos de red, Monitorear conectividad, Resolver incidencias de red, Implementar medidas de seguridad','$700 - $1,200 USD','Tiempo Completo','Caracas, Venezuela','3-6 años','Ingeniero en Telecomunicaciones','2025-11-01',0,1,0,1,'2025-10-07 16:29:28','2025-10-07 16:29:28'),
(4,4,'Comandante Airbus A320','Comandante experimentado para operar aeronaves Airbus A320 en rutas nacionales e internacionales.','Licencia ATPL vigente, Type Rating A320, Experiencia mínima 3000 horas de vuelo, Inglés nivel 4 OACI mínimo','Operar aeronaves con seguridad, Supervisar tripulación, Cumplir procedimientos operacionales, Mantener estándares de seguridad','$2,500 - $4,000 USD','Tiempo Completo','Base Caracas','5+ años','Piloto Comercial','2025-12-01',0,1,0,1,'2025-10-07 16:29:28','2025-10-07 16:29:28'),
(5,5,'Auxiliar de Vuelo','Auxiliar de vuelo para brindar excelente servicio a nuestros pasajeros en vuelos nacionales e internacionales.','Curso de auxiliar de vuelo certificado, Inglés intermedio-avanzado, Excelente presentación personal, Disponibilidad de horarios','Atender pasajeros durante el vuelo, Aplicar procedimientos de seguridad, Servicio de alimentos y bebidas, Asistencia en emergencias','$400 - $800 USD','Tiempo Completo','Base Caracas','0-2 años','Bachiller, Curso TCP','2025-11-20',0,1,0,1,'2025-10-07 16:29:28','2025-10-07 16:29:28'),
(6,7,'Agente de Ventas','Agente de ventas para atención al público en counter del aeropuerto y venta de boletos.','Experiencia en ventas, Conocimiento de sistemas de reservas (deseable), Excelente atención al cliente, Manejo de inglés básico','Atender clientes en counter, Procesar reservas y ventas, Coordinar con otras áreas, Cumplir metas de ventas','$350 - $600 USD','Tiempo Completo','Aeropuerto Maiquetía','1-3 años','Bachiller o TSU','2025-10-25',0,1,0,1,'2025-10-07 16:29:28','2025-10-07 16:29:28'),
(7,9,'Especialista en Atención al Cliente','Especialista para call center de atención al cliente, manejo de consultas y reclamos.','Experiencia en call center, Excelente comunicación verbal, Paciencia y empatía, Conocimiento básico de sistemas','Atender llamadas de clientes, Resolver consultas y reclamos, Registrar incidencias, Seguimiento de casos','$300 - $500 USD','Tiempo Completo','Caracas, Venezuela','1-2 años','Bachiller','2025-11-10',0,1,0,1,'2025-10-07 16:29:28','2025-10-07 16:29:28'),
(8,10,'Analista de Recursos Humanos','Analista de RRHH para apoyar en procesos de reclutamiento, selección y administración de personal.','Licenciatura en RRHH o Psicología, Experiencia en reclutamiento, Conocimiento de leyes laborales, MS Office avanzado','Gestionar procesos de reclutamiento, Realizar entrevistas, Administrar expedientes, Apoyar en capacitación','$500 - $900 USD','Tiempo Completo','Caracas, Venezuela','2-4 años','Licenciado en RRHH','2025-11-05',0,1,0,1,'2025-10-07 16:29:28','2025-10-07 16:29:28');

/*Table structure for table `roles` */

DROP TABLE IF EXISTS `roles`;

CREATE TABLE `roles` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(50) NOT NULL,
  `description` text DEFAULT NULL,
  `created_at` timestamp NOT NULL DEFAULT current_timestamp(),
  PRIMARY KEY (`id`),
  UNIQUE KEY `name` (`name`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

/*Data for the table `roles` */

insert  into `roles`(`id`,`name`,`description`,`created_at`) values 
(1,'Super Admin','Acceso completo al sistema','2025-10-07 16:28:48'),
(2,'Admin','Administrador con acceso limitado','2025-10-07 16:28:48'),
(3,'HR Manager','Gestor de recursos humanos','2025-10-07 16:28:48'),
(4,'Viewer','Solo visualización','2025-10-07 16:28:48');

/*Table structure for table `settings` */

DROP TABLE IF EXISTS `settings`;

CREATE TABLE `settings` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `setting_key` varchar(100) NOT NULL,
  `setting_value` text DEFAULT NULL,
  `description` text DEFAULT NULL,
  `updated_at` timestamp NOT NULL DEFAULT current_timestamp() ON UPDATE current_timestamp(),
  PRIMARY KEY (`id`),
  UNIQUE KEY `setting_key` (`setting_key`)
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

/*Data for the table `settings` */

insert  into `settings`(`id`,`setting_key`,`setting_value`,`description`,`updated_at`) values 
(1,'company_name','Turpial Airlines, C.A.','Nombre de la empresa','2025-10-07 16:28:48'),
(2,'company_email','gerenciarrhh@turpialairlines.net','Email principal de la empresa','2025-10-13 11:23:27'),
(3,'company_phone','+58-212-555-0123','Teléfono principal','2025-10-07 16:28:48'),
(4,'company_address','Aeropuerto Internacional Arturo Michelena, Local 1, Turpial Airlines,C.A.','Dirección de la empresa','2025-10-13 11:25:52'),
(5,'max_cv_size','5242880','Tamaño máximo de CV en bytes (5MB)','2025-10-07 16:28:48'),
(6,'allowed_cv_formats','pdf,doc,docx','Formatos de CV permitidos','2025-10-07 16:28:48');

/*Table structure for table `users` */

DROP TABLE IF EXISTS `users`;

CREATE TABLE `users` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `username` varchar(50) NOT NULL,
  `email` varchar(100) NOT NULL,
  `password` varchar(255) NOT NULL,
  `full_name` varchar(100) NOT NULL,
  `role_id` int(11) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT 1,
  `created_at` timestamp NOT NULL DEFAULT current_timestamp(),
  `updated_at` timestamp NOT NULL DEFAULT current_timestamp() ON UPDATE current_timestamp(),
  PRIMARY KEY (`id`),
  UNIQUE KEY `username` (`username`),
  UNIQUE KEY `email` (`email`),
  KEY `role_id` (`role_id`),
  CONSTRAINT `users_ibfk_1` FOREIGN KEY (`role_id`) REFERENCES `roles` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

/*Data for the table `users` */

insert  into `users`(`id`,`username`,`email`,`password`,`full_name`,`role_id`,`is_active`,`created_at`,`updated_at`) values 
(1,'admin','admin@turpialairlines.com','$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi','Administrador Principal',1,1,'2025-10-07 16:28:48','2025-10-07 16:28:48'),
(2,'hr_manager','rrhh@turpialairlines.com','$2y$10$wdC2jQaZrVjFkC5Euf5J5.VMtaldAK1dXjyZbftGMXNjzc0n5TFJa','Gerente de RRHH',3,1,'2025-10-07 16:28:48','2025-10-13 12:24:14');

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;
